@@ -1,5 +1,5 @@
 ﻿/*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -314,7 +314,7 @@ void KNoteCollectionConfigWidget::updateCollectionsRecursive()
     while (i.hasNext()) {
         i.next();
         Akonadi::Collection collection = i.key();
-        Akonadi::CollectionModifyJob *modifyJob = Q_NULLPTR;
+        Akonadi::CollectionModifyJob *modifyJob = nullptr;
         NoteShared::ShowFolderNotesAttribute *attr = collection.attribute<NoteShared::ShowFolderNotesAttribute>();
         const bool selected = i.value();
         if (selected && !attr) {
