@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -52,7 +52,7 @@ QString KNotePrintObject::description() const
 QString KNotePrintObject::name() const
 {
     KMime::Message::Ptr noteMessage = mItem.payload<KMime::Message::Ptr>();
-    const KMime::Headers::Subject *const subject = noteMessage ? noteMessage->subject(false) : Q_NULLPTR;
+    const KMime::Headers::Subject *const subject = noteMessage ? noteMessage->subject(false) : nullptr;
     return subject ? subject->asUnicodeString() : QString();
 }
 
